@@ -707,9 +707,8 @@ namespace Segs {
                                                   u, u, u, u, u, u, u, u,
                                                   INV_F};
 
-    void align_init(Align *self, const int parse_mods_threshold) {
+    void align_init(Align *self, const int parse_mods_threshold, const bool add_clip_space) {
 //        auto start = std::chrono::high_resolution_clock::now();
-
         bam1_t *src = self->delegate;
 
         self->pos = src->core.pos;
@@ -766,8 +765,13 @@ namespace Segs {
             }
         }
         self->reference_end = self->blocks.back().end;
-        self->cov_start = (int)self->pos - self->left_soft_clip;
-        self->cov_end = (int)self->reference_end + self->right_soft_clip;
+        if (add_clip_space) {
+            self->cov_start = (int)self->pos - self->left_soft_clip;
+            self->cov_end = (int)self->reference_end + self->right_soft_clip;
+        } else {
+            self->cov_start = (int)self->pos;
+            self->cov_end = (int)self->reference_end;
+        }
 
         uint32_t flag = src->core.flag;
 
@@ -777,17 +781,6 @@ namespace Segs {
             self->has_SA = false;
         }
 
-//        if (sort_state > 0) {
-//            if (sort_state == Utils::SortType::HP) {
-//                uint8_t *HP_tag = bam_aux_get(self->delegate, "HP");
-//                self->sort_tag = (HP_tag != nullptr) ? (int) bam_aux2i(HP_tag) : 0;
-//            } else if (sort_state == Utils::SortType::STRAND) {
-//                self->sort_tag = (int)(src->core.flag & BAM_FREVERSE) ? 1 : 0;
-//            } else if (sort_by_pos >= 0 && ref_base != '\0') {
-//                self->sort_tag = getSortCode(src, sort_by_pos, ref_base);
-//            }
-//        }
-
         if (parse_mods_threshold > 0) {
             hts_base_mod_state* mod_state = new hts_base_mod_state;
             int res = bam_parse_basemod_gw(src, mod_state, 0);
@@ -853,17 +846,18 @@ namespace Segs {
         self->any_ins.clear();
     }
 
-    void init_parallel(std::vector<Align> &aligns, int n, BS::thread_pool &pool, const int parse_mods_threshold) {
+    void init_parallel(std::vector<Align> &aligns, const int n, BS::thread_pool &pool,
+        const int parse_mods_threshold, const bool add_clip_space) {
         if (n == 1) {
             for (auto &aln : aligns) {
-                align_init(&aln, parse_mods_threshold);
+                align_init(&aln, parse_mods_threshold, add_clip_space);
             }
         } else {
             pool.parallelize_loop(0, aligns.size(),
-                                  [&aligns, parse_mods_threshold]
+                                  [&aligns, parse_mods_threshold, add_clip_space]
                                   (const int a, const int b) {
                                       for (int i = a; i < b; ++i)
-                                          align_init(&aligns[i], parse_mods_threshold);
+                                          align_init(&aligns[i], parse_mods_threshold, add_clip_space);
                                   })
                     .wait();
         }
@@ -945,7 +939,6 @@ namespace Segs {
         }
     }
 
-
     int getSortCodes(std::vector<Align> &aligns, const int threads, BS::thread_pool &pool, Utils::Region *region) {
         // Lazily returns a sort code for POS, or returns other sort code
         Utils::SortType sort_state = region->getSortOption();
@@ -961,11 +954,22 @@ namespace Segs {
         return sort_state;
     }
 
-    EXPORT ReadCollection::ReadCollection() {
-        vScroll = 0;
-        collection_processed = false;
-        skipDrawingReads = false;
-        skipDrawingCoverage = false;
+//    EXPORT ReadCollection::ReadCollection() {
+//        vScroll = 0;
+//        bamIdx = 0;
+//        regionIdx = 0;
+//        collection_processed = false;
+//        skipDrawingReads = false;
+//        skipDrawingCoverage = false;
+//    }
+
+    void ReadCollection::makeEmptyMMArray() {
+        if (region == nullptr) {
+            return;
+        }
+        mmVector.resize(region->end - region->start + 1);
+        Mismatches empty_mm = {0, 0, 0, 0};
+        std::fill(mmVector.begin(), mmVector.end(), empty_mm);
     }
 
     void ReadCollection::clear() {
@@ -974,12 +978,39 @@ namespace Segs {
         std::fill(covArr.begin(), covArr.end(), 0);
         linked.clear();
         collection_processed = false;
-        for (auto &item: readQueue) {
-            bam_destroy1(item.delegate);
+        if (ownsBamPtrs) {
+            for (auto &item: readQueue) {
+                bam_destroy1(item.delegate);
+            }
         }
         readQueue.clear();
     }
 
+    void ReadCollection::resetDrawState() {
+        skipDrawingReads = false;
+        skipDrawingCoverage = false;
+    }
+
+    // Add or remove soft-clip space for alignments
+    void ReadCollection::modifySOftClipSpace(bool add_soft_clip_space) {
+        for (auto &align : readQueue) {
+            if (align.left_soft_clip) {
+                if (add_soft_clip_space && (int)align.pos == align.cov_start) {
+                    align.cov_start -= align.left_soft_clip;
+                } else if (!add_soft_clip_space && (int)align.pos > align.cov_start) {
+                    align.cov_start = (int)align.pos;
+                }
+            }
+            if (align.right_soft_clip) {
+                if (add_soft_clip_space && (int)align.reference_end == align.cov_end) {
+                    align.cov_end += align.right_soft_clip;
+                } else if (!add_soft_clip_space && (int)align.reference_end < align.cov_end) {
+                    align.cov_end = align.reference_end;
+                }
+            }
+        }
+    }
+
     void resetCovStartEnd(ReadCollection &cl) {
         for (auto &a: cl.readQueue) {
             a.cov_start = (a.left_soft_clip == 0) ? (int)a.pos : (int)a.pos - a.left_soft_clip;
@@ -992,7 +1023,7 @@ namespace Segs {
         }
     }
 
-    void addToCovArray(std::vector<int> &arr, const Align &align, const uint32_t begin, const uint32_t end, const uint32_t l_arr) noexcept {
+    void addToCovArray(std::vector<int> &arr, const Align &align, const uint32_t begin, const uint32_t end) noexcept {
         size_t n_blocks = align.blocks.size();
         for (size_t idx=0; idx < n_blocks; ++idx) {
             uint32_t block_s = align.blocks[idx].start;
