@@ -21,7 +21,7 @@
 
 #define SK_GL
 
-#ifndef OLD_SKIA
+#if !defined(OLD_SKIA) || OLD_SKIA == 0
     #include "include/gpu/ganesh/GrBackendSurface.h"
     #include "include/gpu/ganesh/GrDirectContext.h"
     #include "include/gpu/ganesh/gl/GrGLInterface.h"
